@@ -12,9 +12,19 @@ function(twsconn,Contract,Order)
 
   con <- twsconn[[1]]
 
- #VERSION <- "28" # Version as of API 9.62
-  VERSION <- "29" # Version as of API 9.63
- #VERSION <- "30" # Version as of API 9.64
+  # This is the version of placeOrder() only. It has nothing to do with
+  # the server version. But it does determine the fields that we need to
+  # send for each order!
+  # from official IB API
+
+  #VERSION <- "28" # Version as of API 9.62
+  #VERSION <- "29" # Version as of API 9.63
+  #VERSION <- "30" # Version as of API 9.64
+  VERSION <- "42"
+
+  if(is.null(Order$hedgeType) || is.null(Order$hedgeParam))
+    stop("NEW twsOrder has to be used")
+
   if(Order$orderId == "")
     Order$orderId <- reqIds(twsconn)
 
@@ -22,6 +32,7 @@ function(twsconn,Contract,Order)
   order <- c(.twsOutgoingMSG$PLACE_ORDER,
              VERSION,
              as.character(Order$orderId),
+             as.character(Contract$conId),
              Contract$symbol,
              Contract$sectype,
              Contract$expiry,
@@ -32,6 +43,7 @@ function(twsconn,Contract,Order)
              Contract$primary,
              Contract$currency,
              Contract$local,
+             {if(is.null(Contract$tradingClass)) "" else Contract$tradingClass},
 
              # as of 9.63
              Contract$secIdType,
@@ -58,6 +70,7 @@ function(twsconn,Contract,Order)
              Order$hidden)
 
   if(Contract$sectype == "BAG") {
+    stop("BAG security type not supported")
     if(is.null(Contract$comboleg)) {
       order <- c(order, 0)
     } else {
@@ -88,6 +101,7 @@ function(twsconn,Contract,Order)
              Order$faProfile,
              Order$shortSaleSlot,
              Order$designatedLocation,
+             Order$exemptCode,
              Order$ocaType,
              Order$rule80A,
              Order$settlingFirm,
@@ -108,19 +122,52 @@ function(twsconn,Contract,Order)
              Order$volatilityType,
              Order$deltaNeutralOrderType,
              Order$deltaNeutralAuxPrice,
+             # ... some here if we have deltaNeutralOrderType. but not using it
+             # "0",  #Order$deltaNeutralConId
+             # "",   #Order$deltaNeutralSettlingFirm
+             # "",   #Order$deltaNeutralClearingAccount
+             # "",   #Order$deltaNeutralClearingIntent
+             # "",   #Order$deltaNeutralOpenClose
+             # "0",   #Order$deltaNeutralShortSale
+             # "0",  #Order$deltaNeutralShortSaleSlot
+             # "",   #Order$deltaNeutralDesignatedLocation
              Order$continuousUpdate,
              Order$referencePriceType,
              Order$trailStopPrice,
+             Order$trailingPercent,
              Order$scaleInitLevelSize,
              Order$scaleSubsLevelSize,
              Order$scalePriceIncrement,
+             # .... some here if we have scalePriceIncrement. but not using it
+             # if (Order$scalePriceIncrement != "")
+             #   order <- c(order,
+             #     "1.0", #Order$scalePriceAdjustValue
+             #     "1", #Order$scalePriceAdjustInterval
+             #     "1.0", #Order$scaleProfitOffset
+             #     "0", #Order$scaleAutoReset
+             #     "1", #Order$scaleInitPosition
+             #     "1", #Order$scaleInitFillQty
+             #     "0" #Order$scaleRandomPercent
+             #   )
+             Order$scaleTable,
+             Order$activeStartTime,
+             Order$activeStopTime)
+
+  if(Order$hedgeType != "") {
+    order <- c(order, Order$hedgeType, Order$hedgeParam)
+  } else {
+    order <- c(order, Order$hedgeType)
+  }
+
+  order <- c(order,
+             Order$optOutSmartRouting,
              Order$clearingAccount,
              Order$clearingIntent,
              Order$notHeld,
              "0", # Order$underComp .. not yet supported by IBrokers
-             "",  # Order$algoStrategy .. not yet supported by IBrokers
-             Order$whatIf
-             )
+             Order$algoStrategy,
+             Order$whatIf,
+             "")
 # }}}
 
   writeBin(order, con)  
