@@ -17,19 +17,21 @@
 
 reqIds <- function(conn, numIds=1)
 {
-  if(inherits(conn, "twsconn")) {
-    id <- conn$nextValidId
-    conn$nextValidId <- as.character(as.numeric(id)+1L)
-    return(id)
+  if(!is.twsConnection(conn)) {
+    stop("requires twsConnection object")
   }
-  .reqIds(conn, numIds)
-
   con <- conn[[1]]
-  e_next_id <- eWrapper()
+
+  VERSION <- "1"
+  writeBin(.twsOutgoingMSG$REQ_IDS, con)
+  writeBin(VERSION, con)
+  writeBin(as.character(numIds), con)
+
+  e_next_id <- eWrapper(NULL)
   e_next_id$nextValidId <- function(curMsg, msg, timestamp, file, ...) { msg[2] }
 
   while(TRUE) {
-    socketSelect(list(con), FALSE, NULL)
+    socketSelect(list(con), FALSE, 0.1)
     curMsg <- readBin(con, character(), 1)
 
     nextValidID <- processMsg(curMsg,
