@@ -9,6 +9,17 @@ twsConnect <- twsConnect2 <- function(clientId=1, host="localhost",
                                       port=7496, verbose=TRUE,
                                       timeout=5, filename=NULL,
                                       blocking=.Platform$OS.type=="windows") {
+   startApi <- function(conn, clientId) {
+     if (!is.twsConnection(conn)) {
+       stop("requires twsConnection object")
+     }
+     con <- conn[[1]]
+     VERSION <- "1"
+     writeBin(.twsOutgoingMSG$START_API, con)
+     writeBin(VERSION, con)
+     writeBin(as.character(clientId), con)
+   }
+
    if(is.null(getOption('digits.secs'))) 
      options(digits.secs=6)
 
@@ -25,19 +36,20 @@ twsConnect <- twsConnect2 <- function(clientId=1, host="localhost",
        close(s)
        stop(paste("couldn't connect to TWS on port",port))
      }
-     CLIENT_VERSION <- "47"
+     CLIENT_VERSION <- "63"
 
-     writeBin(c(CLIENT_VERSION,as.character(clientId)), s)
+     writeBin(CLIENT_VERSION, s)
 
      eW <- eWrapper(NULL)
      eW$.Data <- environment()
-     SERVER_VERSION <- NEXT_VALID_ID <- NULL
+     SERVER_VERSION <- NEXT_VALID_ID <- CONNECTION_TIME <- NULL
      eW$nextValidId <- function(curMsg, msg, timestamp, file, ...) {
        eW$.Data$NEXT_VALID_ID <- msg[2]
      }
      
+     # server version and connection time
      while(TRUE) {
-       if( !is.null(NEXT_VALID_ID))
+       if( !is.null(CONNECTION_TIME))
          break
        if( !socketSelect(list(s), FALSE, 0.1))
          next
@@ -49,15 +61,6 @@ twsConnect <- twsConnect2 <- function(clientId=1, host="localhost",
          next
        }
 
-       if(curMsg == .twsIncomingMSG$ERR_MSG) {
-         errMsg <- readBin(s, character(), 4)
-         close(s)
-         on.exit()
-         return( twsConnect(clientId+1, host, port, verbose, timeout, filename, blocking) )
-       }
-
-       processMsg(curMsg, s, eW, NULL, "")
-
        if(Sys.time()-start.time > timeout) {
          close(s)
          stop('tws connection timed-out')
@@ -74,6 +77,32 @@ twsConnect <- twsConnect2 <- function(clientId=1, host="localhost",
      twsconn$connected.at <- CONNECTION_TIME
      twsconn$connected <- NULL # not yet used
      class(twsconn) <- c("twsconn","environment")
+
+     # set the clientId (needs an API call now)
+     startApi(twsconn, clientId)
+
+     # server responds with:
+     # 1) managed account message
+     # 2) next valid id
+     # 3) status messages about data farms (market and time)
+     #    these are 'errors', but the id is -1
+     while(TRUE) {
+       if(socketSelect(list(s), FALSE, 0.1)) {
+         curMsg <- readBin(s, character(), 1)
+         if(curMsg == .twsIncomingMSG$MANAGED_ACCTS) {
+           processMsg(curMsg, s, eW, NULL, "")
+         } else
+         if(curMsg == .twsIncomingMSG$NEXT_VALID_ID) {
+           twsconn$nextValidId <- processMsg(curMsg, s, eW, NULL, "")
+         } else
+         if(curMsg == .twsIncomingMSG$ERR_MSG) {
+           processMsg(curMsg, s, eW, NULL, "")
+         }
+       } else {
+         break
+       }
+     }
+
      return(twsconn)
   } else { 
     #file is defined - not a real connection
