@@ -1,53 +1,100 @@
 `.lastRequest` <- 10
 
+`.IBAPI.VERSION` <- "clientV63" # client Version 63
+
 `.twsOutgoingMSG` <-
-structure(list(REQ_MKT_DATA = "1", CANCEL_MKT_DATA = "2", PLACE_ORDER = "3", 
-    CANCEL_ORDER = "4", REQ_OPEN_ORDERS = "5", REQ_ACCOUNT_DATA = "6", 
-    REQ_EXECUTIONS = "7", REQ_IDS = "8", REQ_CONTRACT_DATA = "9", 
-    REQ_MKT_DEPTH = "10", CANCEL_MKT_DEPTH = "11", REQ_NEWS_BULLETINS = "12", 
-    CANCEL_NEWS_BULLETINS = "13", SET_SERVER_LOGLEVEL = "14", 
-    REQ_AUTO_OPEN_ORDERS = "15", REQ_ALL_OPEN_ORDERS = "16", 
-    REQ_MANAGED_ACCTS = "17", REQ_FA = "18", REPLACE_FA = "19", 
-    REQ_HISTORICAL_DATA = "20", EXERCISE_OPTIONS = "21", REQ_SCANNER_SUBSCRIPTION = "22", 
-    CANCEL_SCANNER_SUBSCRIPTION = "23", REQ_SCANNER_PARAMETERS = "24", 
-    CANCEL_HISTORICAL_DATA = "25", REQ_CURRENT_TIME = "49", REQ_REAL_TIME_BARS = "50", 
-    CANCEL_REAL_TIME_BARS = "51", REQ_FUNDAMENTAL_DATA = "52",
-    CANCEL_FUNDAMENTAL_DATA = "53", REQ_CALC_IMPLIED_VOLAT = "54",
-    REQ_CALC_OPTION_PRICE = "55", CANCEL_CALC_IMPLIED_VOLAT = "56",
-    CANCEL_CALC_OPTION_PRICE = "57"), .Names = c("REQ_MKT_DATA", 
-"CANCEL_MKT_DATA", "PLACE_ORDER", "CANCEL_ORDER", "REQ_OPEN_ORDERS", 
-"REQ_ACCOUNT_DATA", "REQ_EXECUTIONS", "REQ_IDS", "REQ_CONTRACT_DATA", 
-"REQ_MKT_DEPTH", "CANCEL_MKT_DEPTH", "REQ_NEWS_BULLETINS", "CANCEL_NEWS_BULLETINS", 
-"SET_SERVER_LOGLEVEL", "REQ_AUTO_OPEN_ORDERS", "REQ_ALL_OPEN_ORDERS", 
-"REQ_MANAGED_ACCTS", "REQ_FA", "REPLACE_FA", "REQ_HISTORICAL_DATA", 
-"EXERCISE_OPTIONS", "REQ_SCANNER_SUBSCRIPTION", "CANCEL_SCANNER_SUBSCRIPTION", 
-"REQ_SCANNER_PARAMETERS", "CANCEL_HISTORICAL_DATA", "REQ_CURRENT_TIME", 
-"REQ_REAL_TIME_BARS", "CANCEL_REAL_TIME_BARS","REQ_FUNDAMENTAL_DATA","CANCEL_FUNDAMENTAL_DATA",
-"REQ_CALC_IMPLIED_VOLAT","REQ_CALC_OPTION_PRICE","CANCEL_CALC_IMPLIED_VOLAT",
-"CANCEL_CALC_OPTION_PRICE"))
+  list(REQ_MKT_DATA = "1",
+       CANCEL_MKT_DATA = "2",
+       PLACE_ORDER = "3",
+       CANCEL_ORDER = "4",
+       REQ_OPEN_ORDERS = "5",
+       REQ_ACCOUNT_DATA = "6",
+       REQ_EXECUTIONS = "7",
+       REQ_IDS = "8",
+       REQ_CONTRACT_DATA = "9",
+       REQ_MKT_DEPTH = "10",
+       CANCEL_MKT_DEPTH = "11",
+       REQ_NEWS_BULLETINS = "12",
+       CANCEL_NEWS_BULLETINS = "13",
+       SET_SERVER_LOGLEVEL = "14",
+       REQ_AUTO_OPEN_ORDERS = "15",
+       REQ_ALL_OPEN_ORDERS = "16",
+       REQ_MANAGED_ACCTS = "17",
+       REQ_FA = "18",
+       REPLACE_FA = "19",
+       REQ_HISTORICAL_DATA = "20",
+       EXERCISE_OPTIONS = "21",
+       REQ_SCANNER_SUBSCRIPTION = "22",
+       CANCEL_SCANNER_SUBSCRIPTION = "23",
+       REQ_SCANNER_PARAMETERS = "24",
+       CANCEL_HISTORICAL_DATA = "25",
+       REQ_CURRENT_TIME = "49",
+       REQ_REAL_TIME_BARS = "50",
+       CANCEL_REAL_TIME_BARS = "51",
+       REQ_FUNDAMENTAL_DATA = "52",
+       CANCEL_FUNDAMENTAL_DATA = "53",
+       REQ_CALC_IMPLIED_VOLAT = "54",
+       REQ_CALC_OPTION_PRICE = "55",
+       CANCEL_CALC_IMPLIED_VOLAT = "56",
+       CANCEL_CALC_OPTION_PRICE = "57",
+       REQ_GLOBAL_CANCEL = "58",
+       REQ_MARKET_DATA_TYPE = "59",
+       REQ_POSITIONS = "61",
+       REQ_ACCOUNT_SUMMARY = "62",
+       CANCEL_ACCOUNT_SUMMARY = "63",
+       CANCEL_POSITIONS = "64",
+       VERIFY_REQUEST = "65",
+       VERIFY_MESSAGE = "66",
+       QUERY_DISPLAY_GROUPS = "67",
+       SUBSCRIBE_TO_GROUP_EVENTS = "68",
+       UPDATE_DISPLAY_GROUP = "69",
+       UNSUBSCRIBE_FROM_GROUP_EVENTS = "70",
+       START_API = "71")
 
 `.twsIncomingMSG` <-
-structure(list(TICK_PRICE = "1", TICK_SIZE = "2", 
-    ORDER_STATUS = "3", ERR_MSG = "4", OPEN_ORDER = "5", ACCT_VALUE = "6", 
-    PORTFOLIO_VALUE = "7", ACCT_UPDATE_TIME = "8", NEXT_VALID_ID = "9", 
-    CONTRACT_DATA = "10", EXECUTION_DATA = "11", MARKET_DEPTH = "12", 
-    MARKET_DEPTH_L2 = "13", NEWS_BULLETINS = "14", MANAGED_ACCTS = "15", 
-    RECEIVE_FA = "16", HISTORICAL_DATA = "17", BOND_CONTRACT_DATA = "18", 
-    SCANNER_PARAMETERS = "19", SCANNER_DATA = "20", TICK_OPTION_COMPUTATION = "21", 
-    TICK_GENERIC = "45", TICK_STRING = "46", TICK_EFP = "47", 
-    CURRENT_TIME = "49", REAL_TIME_BARS = "50", FUNDAMENTAL_DATA = "51",
-    CONTRACT_DATA_END = "52", OPEN_ORDER_END = "53",
-    ACCT_DOWNLOAD_END = "54", EXECUTION_DATA_END = "55",
-    DELTA_NEUTRAL_VALIDATION = "56", TICK_SNAPSHOT_END = "57"), .Names = c("TICK_PRICE", 
-"TICK_SIZE", "ORDER_STATUS", "ERR_MSG", "OPEN_ORDER", "ACCT_VALUE", 
-"PORTFOLIO_VALUE", "ACCT_UPDATE_TIME", "NEXT_VALID_ID", "CONTRACT_DATA", 
-"EXECUTION_DATA", "MARKET_DEPTH", "MARKET_DEPTH_L2", "NEWS_BULLETINS", 
-"MANAGED_ACCTS", "RECEIVE_FA", "HISTORICAL_DATA", "BOND_CONTRACT_DATA", 
-"SCANNER_PARAMETERS", "SCANNER_DATA", "TICK_OPTION_COMPUTATION", 
-"TICK_GENERIC", "TICK_STRING", "TICK_EFP", "CURRENT_TIME", "REAL_TIME_BARS",
-"FUNDAMENTAL_DATA","CONTRACT_DATA_END", "OPEN_ORDER_END", "ACCT_DOWNLOAD_END",
-"EXECUTION_DATA_END","DELTA_NEUTRAL_VALIDATION","TICK_SNAPSHOT_END"
-))
+  list(TICK_PRICE = "1",
+       TICK_SIZE = "2",
+       ORDER_STATUS = "3",
+       ERR_MSG = "4",
+       OPEN_ORDER = "5",
+       ACCT_VALUE = "6",
+       PORTFOLIO_VALUE = "7",
+       ACCT_UPDATE_TIME = "8",
+       NEXT_VALID_ID = "9",
+       CONTRACT_DATA = "10",
+       EXECUTION_DATA = "11",
+       MARKET_DEPTH = "12",
+       MARKET_DEPTH_L2 = "13",
+       NEWS_BULLETINS = "14",
+       MANAGED_ACCTS = "15",
+       RECEIVE_FA = "16",
+       HISTORICAL_DATA = "17",
+       BOND_CONTRACT_DATA = "18",
+       SCANNER_PARAMETERS = "19",
+       SCANNER_DATA = "20",
+       TICK_OPTION_COMPUTATION = "21",
+       TICK_GENERIC = "45",
+       TICK_STRING = "46",
+       TICK_EFP = "47",
+       CURRENT_TIME = "49",
+       REAL_TIME_BARS = "50",
+       FUNDAMENTAL_DATA = "51",
+       CONTRACT_DATA_END = "52",
+       OPEN_ORDER_END = "53",
+       ACCT_DOWNLOAD_END = "54",
+       EXECUTION_DATA_END = "55",
+       DELTA_NEUTRAL_VALIDATION = "56",
+       TICK_SNAPSHOT_END = "57",
+       MARKET_DATA_TYPE = "58",
+       COMMISSION_REPORT = "59",
+       POSITION_DATA = "61",
+       POSITION_END = "62",
+       ACCOUNT_SUMMARY = "63",
+       ACCOUNT_SUMMARY_END = "64",
+       VERIFY_MESSAGE_API = "65",
+       VERIFY_COMPLETED = "66",
+       DISPLAY_GROUP_LIST = "67",
+       DISPLAY_GROUP_UPDATED = "68")
 
 `.twsERR` <-
 structure(c("Max rate of messages per second has been exceeded.", 
