@@ -14,7 +14,7 @@ twsPortfolioValue.AccountUpdate <- function(x, zero.pos=TRUE, ...) {
                               sectype=x$contract$sectype,
                               marketValue=x[[2]]$marketValue, 
                               averageCost=x[[2]]$averageCost*x[[2]]$position,
-                              return=with(x[[2]],marketValue/(averageCost*position)-1),
+                              return=with(x[[2]],(marketValue/(averageCost*position)-1) * sign(position)),
                               position=x[[2]]$position, 
                               realizedPNL=x[[2]]$realizedPNL,
                               unrealizedPNL=x[[2]]$unrealizedPNL)))
