@@ -48,7 +48,8 @@ structure(list(
      LAST_TIMESTAMP = 45,
      SHORTABLE = 46,
      FUNDAMENTAL_RATIOS = 47,
-     RT_VOLUME = 48),
+     RT_VOLUME = 48,
+     HALTED = 49),
  .Names=c( "BID_SIZE","BID","ASK","ASK_SIZE","LAST","LAST_SIZE",
 "HIGH","LOW","VOLUME","CLOSE","BID_OPTION",
 "ASK_OPTION","LAST_OPTION","MODEL_OPTION","OPEN","LOW_13_WEEK",
@@ -60,4 +61,4 @@ structure(list(
 "BID_EXCH","ASK_EXCH","AUCTION_VOLUME","AUCTION_PRICE",
 "AUCTION_IMBALANCE","MARK_PRICE","BID_EFP_COMPUTATION","ASK_EFP_COMPUTATION",
 "LAST_EFP_COMPUTATION","OPEN_EFP_COMPUTATION","HIGH_EFP_COMPUTATION","LOW_EFP_COMPUTATION",
-"CLOSE_EFP_COMPUTATION","LAST_TIMESTAMP","SHORTABLE","FUNDAMENTAL_RATIOS","RT_VOLUME"))
+"CLOSE_EFP_COMPUTATION","LAST_TIMESTAMP","SHORTABLE","FUNDAMENTAL_RATIOS","RT_VOLUME","HALTED"))
